@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * goc-text.h:
  *
@@ -26,7 +27,6 @@
 
 G_BEGIN_DECLS
 
-
 struct _GocText {
 	GocStyledItem base;
 
@@ -35,9 +35,9 @@ struct _GocText {
 	gboolean clipped;
 	double clip_width, clip_height, wrap_width;
 	char *text;
-	GOAnchorType anchor;
+	GtkAnchorType anchor;
 	PangoAttrList *attributes;
-	gpointer priv;
+	PangoLayout *layout;
 };
 
 typedef GocStyledItemClass GocTextClass;
