@@ -1,12 +1,12 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * goffice.h :
  *
  * Copyright (C) 2003-2005 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) version 3.
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,27 +22,19 @@
 #define GOFFICE_H
 
 #include <glib.h>
-#include <glib-object.h>
-#include <gsf/gsf.h>
 #include <goffice/goffice-features.h>
 
-#ifdef GOFFICE_WITH_DECIMAL64
-#ifdef __GI_SCANNER__
-// Wrong, of course, but the introspection scanner does not know _Decimal64
-typedef double _Decimal64;
-#endif
-#endif
-
 #ifdef GOFFICE_WITH_GTK
 #include <gtk/gtk.h>
-#endif
+#else
 #include <cairo/cairo.h>
 #include <pango/pango.h>
+#endif
 
 #ifndef GO_VAR_DECL
 #  ifdef WIN32
 #    ifdef GOFFICE_COMPILATION
-#      define GO_VAR_DECL extern __declspec(dllexport)
+#      define GO_VAR_DECL __declspec(dllexport)
 #    else
 #      define GO_VAR_DECL extern __declspec(dllimport)
 #    endif
@@ -51,13 +43,21 @@ typedef double _Decimal64;
 #  endif
 #endif /* GO_VAR_DECL */
 
-#ifdef G_DEPRECATED_FOR
-#define GOFFICE_DEPRECATED_FOR(f) G_DEPRECATED_FOR(f)
-#else
-#define GOFFICE_DEPRECATED_FOR(f)
+
+#include <glib-object.h>
+#ifdef GOFFICE_WITH_GTK
+#include <gtk/gtk.h>
 #endif
 
 #include <goffice/app/goffice-app.h>
+#include <goffice/utils/goffice-utils.h>
+#include <goffice/data/goffice-data.h>
+#include <goffice/math/goffice-math.h>
+#include <goffice/graph/goffice-graph.h>
+#ifdef GOFFICE_WITH_GTK
+#include <goffice/gtk/goffice-gtk.h>
+#include <goffice/canvas/goffice-canvas.h>
+#endif
 
 G_BEGIN_DECLS
 
