@@ -1,12 +1,12 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gog-grid-line.h
  *
  * Copyright (C) 2004 Emmanuel Pacaud (emmanuel.pacaud@univ-poitiers.fr)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) version 3.
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,6 +34,8 @@ GType gog_grid_line_get_type (void);
 
 gboolean gog_grid_line_is_minor (GogGridLine *ggl);
 
+typedef GogView GogGridLineView;
+
 void gog_grid_line_view_render_stripes (GogView *view);
 void gog_grid_line_view_render_lines (GogView *view);
 
