@@ -1,12 +1,12 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gog-plot-engine.h :
  *
  * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) version 3.
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -51,7 +51,7 @@ GogPlotFamily *gog_plot_family_by_name  (char const *name);
 GogPlotFamily *gog_plot_family_register (char const *name, char const *sample_image_file,
 					 int priority, GogAxisSet axis_set);
 void gog_plot_family_unregister (GogPlotFamily *family);
-GogPlotType   *gog_plot_type_register   (GogPlotFamily *family, int col, int row,
+GogPlotType   *gog_plot_type_register   (GogPlotFamily *famlily, int col, int row,
 					 char const *name, char const *sample_image_file,
 					 char const *description, char const *engine);
 
