@@ -1,12 +1,12 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gog-plot-impl.h : implementation details for the abstract 'plot' interface
  *
  * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) version 3.
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,7 +27,8 @@
 G_BEGIN_DECLS
 
 struct _GogPlotDesc {
-	unsigned int num_series_max;
+	unsigned  num_series_max;
+	unsigned  num_axis;
 	GogSeriesDesc series;
 };
 
@@ -35,11 +36,14 @@ struct _GogPlot {
 	GogObject	 base;
 
 	GSList		*series;
-	unsigned int	 full_cardinality, visible_cardinality;
+	unsigned	 full_cardinality, visible_cardinality;
 	gboolean	 cardinality_valid;
-	unsigned int	 index_num;
+	unsigned	 index_num;
 	gboolean	 vary_style_by_element;
-	GogPlotRenderingOrder rendering_order;
+	union {
+		GogPlotRenderingOrder rendering_order;
+		gboolean render_before_axes; /* Deprecated */
+	};
 	gchar		*plot_group;
 	char		*guru_hints;
 
@@ -76,12 +80,11 @@ typedef struct {
 
 	void       (*update_3d)		(GogPlot *plot);
 	void	   (*guru_helper)	(GogPlot *plot, char const *hint);
-	double	   (*get_percent)       (GogPlot *plot, unsigned series, unsigned index);
 } GogPlotClass;
 
 #define GOG_PLOT_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST ((k), GOG_TYPE_PLOT, GogPlotClass))
 #define GOG_IS_PLOT_CLASS(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), GOG_TYPE_PLOT))
-#define GOG_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_PLOT, GogPlotClass))
+#define GOG_PLOT_ITEM_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_PLOT, GogPlotClass))
 
 /* protected */
 
