@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-path.h
  *
@@ -6,9 +7,8 @@
  * Copyright © 2006 Emmanuel Pacaud (emmanuel.pacaud@lapp.in2p3.fr)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) version 3.
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -51,12 +51,12 @@ typedef struct {
 	double y;
 } GOPathPoint;
 
-typedef void (*GOPathMoveToFunc) 	(void *closure, GOPathPoint const *point);
-typedef void (*GOPathLineToFunc) 	(void *closure, GOPathPoint const *point);
-typedef void (*GOPathCurveToFunc) 	(void *closure, GOPathPoint const *point0,
+typedef void (GOPathMoveToFunc) 	(void *closure, GOPathPoint const *point);
+typedef void (GOPathLineToFunc) 	(void *closure, GOPathPoint const *point);
+typedef void (GOPathCurveToFunc) 	(void *closure, GOPathPoint const *point0,
 					 		GOPathPoint const *point1,
 							GOPathPoint const *point2);
-typedef void (*GOPathClosePathFunc) 	(void *closure);
+typedef void (GOPathClosePathFunc) 	(void *closure);
 
 GType   go_path_get_type (void);
 
@@ -64,10 +64,8 @@ GType   go_path_get_type (void);
 #define GO_IS_PATH(x) ((x) != NULL)
 
 GOPath *go_path_new 	      	(void);
-GOPath *go_path_new_from_svg    (char const *src);
-GOPath *go_path_new_from_odf_enhanced_path (char const *src, GHashTable const *variables);
 void 	go_path_clear	      	(GOPath *path);
-GOPath *go_path_ref          	(GOPath *path);
+void    go_path_ref          	(GOPath *path);
 void    go_path_free          	(GOPath *path);
 
 void    	go_path_set_options  	(GOPath *path, GOPathOptions options);
@@ -100,18 +98,10 @@ void	go_path_rectangle	(GOPath *path, double x, double y,
 
 void	go_path_interpret	(GOPath const *path,
 				 GOPathDirection direction,
-				 GOPathMoveToFunc move_to,
-				 GOPathLineToFunc line_to,
-				 GOPathCurveToFunc curve_to,
-				 GOPathClosePathFunc close_path,
-				 void *closure);
-void	go_path_interpret_full (GOPath const *path,
-	             gssize start, gssize end,
-				 GOPathDirection direction,
-				 GOPathMoveToFunc move_to,
-				 GOPathLineToFunc line_to,
-				 GOPathCurveToFunc curve_to,
-				 GOPathClosePathFunc close_path,
+				 GOPathMoveToFunc *move_to,
+				 GOPathLineToFunc *line_to,
+				 GOPathCurveToFunc *curve_to,
+				 GOPathClosePathFunc *close_path,
 				 void *closure);
 
 void    go_path_to_cairo	(GOPath const *path,
@@ -119,10 +109,7 @@ void    go_path_to_cairo	(GOPath const *path,
 				 cairo_t *cr);
 
 GOPath *go_path_copy		(GOPath const *path);
-GOPath *go_path_copy_restricted	(GOPath const *path, gssize start, gssize end);
 GOPath *go_path_append		(GOPath *path1, GOPath const *path2);
-GOPath *go_path_scale       (GOPath *path, double scale_x, double scale_y);
-char   *go_path_to_svg      (GOPath *path);
 
 G_END_DECLS
 
